@@ -26,6 +26,7 @@
 #include <gst/video/videooverlay.h>
 #include <arv.h>
 #include <arvdebugprivate.h>
+#include <arvviewer.h>
 #include <math.h>
 #include <memory.h>
 #include <libnotify/notify.h>
@@ -113,7 +114,7 @@ gstreamer_plugin_check (void)
 	return check_success;
 }
 
-typedef struct {
+struct  _ArvViewer {
 	GtkApplication parent_instance;
 
 	ArvCamera *camera;
@@ -200,7 +201,7 @@ typedef struct {
 	ArvRegisterCachePolicy cache_policy;
 
 	gulong video_window_xid;
-} ArvViewer;
+};
 
 typedef GtkApplicationClass ArvViewerClass;
 
@@ -444,7 +445,7 @@ gain_scale_cb (GtkRange *range, ArvViewer *viewer)
 	g_signal_handler_unblock (viewer->gain_spin_button, viewer->gain_spin_changed);
 }
 
-gboolean
+static gboolean
 update_exposure_cb (void *data)
 {
 	ArvViewer *viewer = data;
@@ -523,7 +524,7 @@ update_gain_ui (ArvViewer *viewer, gboolean is_auto)
 }
 
 
-void
+static void
 auto_gain_cb (GtkToggleButton *toggle, ArvViewer *viewer)
 {
 	gboolean is_auto;
@@ -537,6 +538,13 @@ auto_gain_cb (GtkToggleButton *toggle, ArvViewer *viewer)
 static void
 set_camera_widgets(ArvViewer *viewer)
 {
+	g_autofree char *string;
+	double gain_min, gain_max;
+	gboolean is_frame_rate_available;
+	gboolean is_gain_available;
+	gboolean is_exposure_available;
+	gboolean auto_gain, auto_exposure;
+
 	g_signal_handler_block (viewer->gain_hscale, viewer->gain_hscale_changed);
 	g_signal_handler_block (viewer->gain_spin_button, viewer->gain_spin_changed);
 	g_signal_handler_block (viewer->exposure_hscale, viewer->exposure_hscale_changed);
@@ -546,7 +554,6 @@ set_camera_widgets(ArvViewer *viewer)
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->exposure_spin_button),
 				   viewer->exposure_min, viewer->exposure_max);
 	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->exposure_spin_button), 200.0, 1000.0);
-	double gain_min, gain_max;
 	arv_camera_get_gain_bounds (viewer->camera, &gain_min, &gain_max, NULL);
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->gain_spin_button), gain_min, gain_max);
 	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->gain_spin_button), 1, 10);
@@ -554,20 +561,16 @@ set_camera_widgets(ArvViewer *viewer)
 	gtk_range_set_range (GTK_RANGE (viewer->exposure_hscale), 0.0, 1.0);
 	gtk_range_set_range (GTK_RANGE (viewer->gain_hscale), gain_min, gain_max);
 
-	gboolean is_frame_rate_available;
 	is_frame_rate_available = arv_camera_is_frame_rate_available (viewer->camera, NULL);
 	gtk_widget_set_sensitive (viewer->frame_rate_entry, is_frame_rate_available);
 
-	g_autofree char *string;
 	string = g_strdup_printf ("%g", arv_camera_get_frame_rate (viewer->camera, NULL));
 	gtk_entry_set_text (GTK_ENTRY (viewer->frame_rate_entry), string);
 
-	gboolean is_gain_available;
 	is_gain_available = arv_camera_is_gain_available (viewer->camera, NULL);
 	gtk_widget_set_sensitive (viewer->gain_hscale, is_gain_available);
 	gtk_widget_set_sensitive (viewer->gain_spin_button, is_gain_available);
 
-	gboolean is_exposure_available;
 	is_exposure_available = arv_camera_is_exposure_time_available (viewer->camera, NULL);
 	gtk_widget_set_sensitive (viewer->exposure_hscale, is_exposure_available);
 	gtk_widget_set_sensitive (viewer->exposure_spin_button, is_exposure_available);
@@ -577,7 +580,6 @@ set_camera_widgets(ArvViewer *viewer)
 	g_signal_handler_unblock (viewer->exposure_hscale, viewer->exposure_hscale_changed);
 	g_signal_handler_unblock (viewer->exposure_spin_button, viewer->exposure_spin_changed);
 
-	gboolean auto_gain, auto_exposure;
 	auto_gain = arv_camera_get_gain_auto (viewer->camera, NULL) != ARV_AUTO_OFF;
 	auto_exposure = arv_camera_get_exposure_time_auto (viewer->camera, NULL) != ARV_AUTO_OFF;
 
@@ -599,7 +601,7 @@ set_camera_widgets(ArvViewer *viewer)
 	g_signal_handler_unblock (viewer->auto_exposure_toggle, viewer->auto_exposure_clicked);
 }
 
-void
+static void
 snapshot_cb (GtkButton *button, ArvViewer *viewer)
 {
 	GFile *file;
@@ -797,7 +799,7 @@ update_camera_region (ArvViewer *viewer)
 	g_signal_handler_unblock (viewer->camera_binning_y, viewer->camera_binning_y_changed);
 }
 
-void
+static void
 camera_region_cb (GtkSpinButton *spin_button, ArvViewer *viewer)
 {
 	int x = gtk_spin_button_get_value (GTK_SPIN_BUTTON (viewer->camera_x));
@@ -810,7 +812,7 @@ camera_region_cb (GtkSpinButton *spin_button, ArvViewer *viewer)
 	update_camera_region (viewer);
 }
 
-void
+static void
 camera_binning_cb (GtkSpinButton *spin_button, ArvViewer *viewer)
 {
 	int dx = gtk_spin_button_get_value (GTK_SPIN_BUTTON (viewer->camera_binning_x));
@@ -821,7 +823,7 @@ camera_binning_cb (GtkSpinButton *spin_button, ArvViewer *viewer)
 	update_camera_region (viewer);
 }
 
-void
+static void
 pixel_format_combo_cb (GtkComboBoxText *combo, ArvViewer *viewer)
 {
 	char *pixel_format;
@@ -831,7 +833,7 @@ pixel_format_combo_cb (GtkComboBoxText *combo, ArvViewer *viewer)
 	g_free (pixel_format);
 }
 
-void
+static void
 update_device_list_cb (GtkToolButton *button, ArvViewer *viewer)
 {
 	GtkListStore *list_store;
@@ -1235,19 +1237,19 @@ select_mode (ArvViewer *viewer, ArvViewerMode mode)
 
 }
 
-void
+static void
 switch_to_camera_list_cb (GtkToolButton *button, ArvViewer *viewer)
 {
 	select_mode (viewer, ARV_VIEWER_MODE_CAMERA_LIST);
 }
 
-void
+static void
 switch_to_video_mode_cb (GtkToolButton *button, ArvViewer *viewer)
 {
 	select_mode (viewer, ARV_VIEWER_MODE_VIDEO);
 }
 
-void
+static void
 arv_viewer_quit_cb (GtkApplicationWindow *window, ArvViewer *viewer)
 {
 	stop_camera (viewer);
